Subject: [PATCH 5/7] myri10ge: Full vlan frame in small_bytes

From: Brice Goglin <[email-masked]>
Date: Mon, 11 Dec 2006 11:26:38 +0100

Receive full vlan frames into smalls when running with a jumbo MTU.

Signed-off-by: Brice Goglin <[email-masked]>
---
 drivers/net/myri10ge/myri10ge.c |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

Index: linux-git/drivers/net/myri10ge/myri10ge.c
===================================================================
--- linux-git.orig/drivers/net/myri10ge/myri10ge.c	2006-12-11 10:52:44.000000000 +0100
+++ linux-git/drivers/net/myri10ge/myri10ge.c	2006-12-11 10:52:51.000000000 +0100
@@ -1650,8 +1650,8 @@
 		    ? (128 - MXGEFW_PAD)
 		    : (SMP_CACHE_BYTES - MXGEFW_PAD);
 	else
-		/* enough for an ETH_DATA_LEN frame */
-		mgp->small_bytes = ETH_FRAME_LEN;
+		/* enough for a vlan encapsulated ETH_DATA_LEN frame */
+		mgp->small_bytes = VLAN_ETH_FRAME_LEN;
 
 	/* Override the small buffer size? */
 	if (myri10ge_small_bytes > 0)